@@ -4,9 +4,11 @@ import os
 import re
 from pathlib import PurePath
 from typing import Optional, Tuple
+from urllib.parse import urlsplit
 
 import ndebug
 from git import GitCommandError, InvalidGitRepositoryError, Repo, TagObject
+from git.exc import BadName
 
 from .errors import GitError, HvcsRepoParseError
 from .settings import config
@@ -32,7 +34,11 @@ def get_commit_log(from_rev=None):
     check_repo()
     rev = None
     if from_rev:
-        rev = '...{from_rev}'.format(from_rev=from_rev)
+        try:
+            repo.commit(from_rev)
+            rev = '...{from_rev}'.format(from_rev=from_rev)
+        except BadName:
+            debug('Reference {} does not exist, considering all log'.format(from_rev))
     for commit in repo.iter_commits(rev):
         yield (commit.hexsha, commit.message)
 
@@ -85,7 +91,9 @@ def get_repository_owner_and_name() -> Tuple[str, str]:
 
     check_repo()
     url = repo.remote('origin').url
-    parts = re.search(r'[:/]([^\.:]+)/([^/]*?)(.git)?$', url)
+    split_url = urlsplit(url)
+    path = split_url.netloc + split_url.path
+    parts = re.search(r'[:/]([^:]+)/([^/]*?)(.git)?$', path)
     if not parts:
         raise HvcsRepoParseError
     debug('get_repository_owner_and_name', parts)
@@ -158,12 +166,22 @@ def push_new_version(
         token = auth_token
         if config.get('semantic_release', 'hvcs') == 'gitlab':
             token = 'gitlab-ci-token:' + token
-        server = 'https://{token}@{server_url}/{owner}/{name}.git'.format(
-            token=token,
-            server_url=domain,
-            owner=owner,
-            name=name,
-        )
+        actor = os.environ.get('GITHUB_ACTOR')
+        if actor:
+            server = 'https://{actor}:{token}@{server_url}/{owner}/{name}.git'.format(
+                token=token,
+                server_url=domain,
+                owner=owner,
+                name=name,
+                actor=actor
+            )
+        else:
+            server = 'https://{token}@{server_url}/{owner}/{name}.git'.format(
+                token=token,
+                server_url=domain,
+                owner=owner,
+                name=name,
+            )
 
     try:
         repo.git.push(server, branch)
